@@ -13,5 +13,8 @@ https://www.github.com/hui2000ji/scETM.
 """
 
 from scETM.logging_utils import initialize_logger
+from scETM.model import scETM
+from scETM.trainer import UnsupervisedTrainer, prepare_for_transfer
+from scETM.eval_utils import evaluate, calculate_entropy_batch_mixing, calculate_kbet, calculate_nearest_neighbors, clustering, draw_embeddings
 
 initialize_logger()
\ No newline at end of file
